@@ -41,10 +41,16 @@
 
 #include "simddefs.h"
 
-#ifdef AF_HASSIMD
+#ifdef AF_HASSIMD_X86
 #include "add_simd_x86.h"
 #endif
 
+#ifdef AF_HASSIMD_ARM
+#include "arm_neon.h"
+#include "add_simd_arm.h"
+#endif
+
+
 /*--------------------------------------------------------------------------- */
 
 /*--------------------------------------------------------------------------- */
@@ -66,7 +72,7 @@ signed int add_signed_char_1(Py_ssize_t arraylen, int nosimd, signed char *data1
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_signed_char_1_simd(arraylen, data1, param);
@@ -112,7 +118,7 @@ signed int add_signed_char_2(Py_ssize_t arraylen, int nosimd, signed char *data1
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_signed_char_2_simd(arraylen, data1, param, data3);
@@ -159,7 +165,7 @@ signed int add_signed_char_3(Py_ssize_t arraylen, int nosimd, signed char param,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_signed_char_3_simd(arraylen, param, data2);
@@ -205,7 +211,7 @@ signed int add_signed_char_4(Py_ssize_t arraylen, int nosimd, signed char param,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_signed_char_4_simd(arraylen, param, data2, data3);
@@ -253,7 +259,7 @@ signed int add_signed_char_5(Py_ssize_t arraylen, int nosimd, signed char *data1
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_signed_char_5_simd(arraylen, data1, data2);
@@ -285,7 +291,7 @@ signed int add_signed_char_6(Py_ssize_t arraylen, int nosimd, signed char *data1
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_signed_char_6_simd(arraylen, data1, data2, data3);
@@ -327,7 +333,7 @@ signed int add_unsigned_char_1(Py_ssize_t arraylen, int nosimd, unsigned char *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_unsigned_char_1_simd(arraylen, data1, param);
@@ -360,7 +366,7 @@ signed int add_unsigned_char_2(Py_ssize_t arraylen, int nosimd, unsigned char *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_unsigned_char_2_simd(arraylen, data1, param, data3);
@@ -393,7 +399,7 @@ signed int add_unsigned_char_3(Py_ssize_t arraylen, int nosimd, unsigned char pa
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_unsigned_char_3_simd(arraylen, param, data2);
@@ -426,7 +432,7 @@ signed int add_unsigned_char_4(Py_ssize_t arraylen, int nosimd, unsigned char pa
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_unsigned_char_4_simd(arraylen, param, data2, data3);
@@ -461,7 +467,7 @@ signed int add_unsigned_char_5(Py_ssize_t arraylen, int nosimd, unsigned char *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_unsigned_char_5_simd(arraylen, data1, data2);
@@ -494,7 +500,7 @@ signed int add_unsigned_char_6(Py_ssize_t arraylen, int nosimd, unsigned char *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			add_unsigned_char_6_simd(arraylen, data1, data2, data3);
@@ -536,7 +542,7 @@ signed int add_signed_short_1(Py_ssize_t arraylen, int nosimd, signed short *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_signed_short_1_simd(arraylen, data1, param);
@@ -582,7 +588,7 @@ signed int add_signed_short_2(Py_ssize_t arraylen, int nosimd, signed short *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_signed_short_2_simd(arraylen, data1, param, data3);
@@ -629,7 +635,7 @@ signed int add_signed_short_3(Py_ssize_t arraylen, int nosimd, signed short para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_signed_short_3_simd(arraylen, param, data2);
@@ -675,7 +681,7 @@ signed int add_signed_short_4(Py_ssize_t arraylen, int nosimd, signed short para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_signed_short_4_simd(arraylen, param, data2, data3);
@@ -723,7 +729,7 @@ signed int add_signed_short_5(Py_ssize_t arraylen, int nosimd, signed short *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_signed_short_5_simd(arraylen, data1, data2);
@@ -755,7 +761,7 @@ signed int add_signed_short_6(Py_ssize_t arraylen, int nosimd, signed short *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_signed_short_6_simd(arraylen, data1, data2, data3);
@@ -797,7 +803,7 @@ signed int add_unsigned_short_1(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_unsigned_short_1_simd(arraylen, data1, param);
@@ -830,7 +836,7 @@ signed int add_unsigned_short_2(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_unsigned_short_2_simd(arraylen, data1, param, data3);
@@ -863,7 +869,7 @@ signed int add_unsigned_short_3(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_unsigned_short_3_simd(arraylen, param, data2);
@@ -896,7 +902,7 @@ signed int add_unsigned_short_4(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_unsigned_short_4_simd(arraylen, param, data2, data3);
@@ -931,7 +937,7 @@ signed int add_unsigned_short_5(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_unsigned_short_5_simd(arraylen, data1, data2);
@@ -964,7 +970,7 @@ signed int add_unsigned_short_6(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			add_unsigned_short_6_simd(arraylen, data1, data2, data3);
@@ -1006,7 +1012,7 @@ signed int add_signed_int_1(Py_ssize_t arraylen, int nosimd, signed int *data1,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_signed_int_1_simd(arraylen, data1, param);
@@ -1052,7 +1058,7 @@ signed int add_signed_int_2(Py_ssize_t arraylen, int nosimd, signed int *data1,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_signed_int_2_simd(arraylen, data1, param, data3);
@@ -1099,7 +1105,7 @@ signed int add_signed_int_3(Py_ssize_t arraylen, int nosimd, signed int param, s
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_signed_int_3_simd(arraylen, param, data2);
@@ -1145,7 +1151,7 @@ signed int add_signed_int_4(Py_ssize_t arraylen, int nosimd, signed int param, s
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_signed_int_4_simd(arraylen, param, data2, data3);
@@ -1193,7 +1199,7 @@ signed int add_signed_int_5(Py_ssize_t arraylen, int nosimd, signed int *data1,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_signed_int_5_simd(arraylen, data1, data2);
@@ -1225,7 +1231,7 @@ signed int add_signed_int_6(Py_ssize_t arraylen, int nosimd, signed int *data1,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_signed_int_6_simd(arraylen, data1, data2, data3);
@@ -1267,7 +1273,7 @@ signed int add_unsigned_int_1(Py_ssize_t arraylen, int nosimd, unsigned int *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_unsigned_int_1_simd(arraylen, data1, param);
@@ -1300,7 +1306,7 @@ signed int add_unsigned_int_2(Py_ssize_t arraylen, int nosimd, unsigned int *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_unsigned_int_2_simd(arraylen, data1, param, data3);
@@ -1333,7 +1339,7 @@ signed int add_unsigned_int_3(Py_ssize_t arraylen, int nosimd, unsigned int para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_unsigned_int_3_simd(arraylen, param, data2);
@@ -1366,7 +1372,7 @@ signed int add_unsigned_int_4(Py_ssize_t arraylen, int nosimd, unsigned int para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_unsigned_int_4_simd(arraylen, param, data2, data3);
@@ -1401,7 +1407,7 @@ signed int add_unsigned_int_5(Py_ssize_t arraylen, int nosimd, unsigned int *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_unsigned_int_5_simd(arraylen, data1, data2);
@@ -1434,7 +1440,7 @@ signed int add_unsigned_int_6(Py_ssize_t arraylen, int nosimd, unsigned int *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			add_unsigned_int_6_simd(arraylen, data1, data2, data3);
@@ -2223,7 +2229,7 @@ signed int add_float_1(Py_ssize_t arraylen, int nosimd, float *data1, float para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			add_float_1_simd(arraylen, data1, param);
@@ -2254,7 +2260,7 @@ signed int add_float_2(Py_ssize_t arraylen, int nosimd, float *data1, float para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			add_float_2_simd(arraylen, data1, param, data3);
@@ -2285,7 +2291,7 @@ signed int add_float_3(Py_ssize_t arraylen, int nosimd, float param, float *data
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			add_float_3_simd(arraylen, param, data2);
@@ -2316,7 +2322,7 @@ signed int add_float_4(Py_ssize_t arraylen, int nosimd, float param, float *data
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			add_float_4_simd(arraylen, param, data2, data3);
@@ -2349,7 +2355,7 @@ signed int add_float_5(Py_ssize_t arraylen, int nosimd, float *data1, float *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			add_float_5_simd(arraylen, data1, data2);
@@ -2380,7 +2386,7 @@ signed int add_float_6(Py_ssize_t arraylen, int nosimd, float *data1, float *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			add_float_6_simd(arraylen, data1, data2, data3);
@@ -2420,7 +2426,7 @@ signed int add_double_1(Py_ssize_t arraylen, int nosimd, double *data1, double p
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			add_double_1_simd(arraylen, data1, param);
@@ -2451,7 +2457,7 @@ signed int add_double_2(Py_ssize_t arraylen, int nosimd, double *data1, double p
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			add_double_2_simd(arraylen, data1, param, data3);
@@ -2482,7 +2488,7 @@ signed int add_double_3(Py_ssize_t arraylen, int nosimd, double param, double *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			add_double_3_simd(arraylen, param, data2);
@@ -2513,7 +2519,7 @@ signed int add_double_4(Py_ssize_t arraylen, int nosimd, double param, double *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			add_double_4_simd(arraylen, param, data2, data3);
@@ -2546,7 +2552,7 @@ signed int add_double_5(Py_ssize_t arraylen, int nosimd, double *data1, double *
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			add_double_5_simd(arraylen, data1, data2);
@@ -2577,7 +2583,7 @@ signed int add_double_6(Py_ssize_t arraylen, int nosimd, double *data1, double *
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			add_double_6_simd(arraylen, data1, data2, data3);
@@ -3061,6 +3067,7 @@ Call formats: \n\
   add(array1, param, maxlen=y) \n\
   add(array1, param, matherrors=False) \n\
   add(array, param, nosimd=False)\n\
+\n\
 * array1 - The first input data array to be examined. If no output  \n\
   array is provided the results will overwrite the input data.  \n\
 * param - A non-array numeric parameter.  \n\
