@@ -47,10 +47,15 @@
 
 #include "simddefs.h"
 
-#ifdef AF_HASSIMD
+#ifdef AF_HASSIMD_X86
 #include "degrees_simd_x86.h"
 #endif
 
+#ifdef AF_HASSIMD_ARM
+#include "arm_neon.h"
+#include "degrees_simd_arm.h"
+#endif
+
 
 /*--------------------------------------------------------------------------- */
 
@@ -75,7 +80,7 @@ signed int degrees_float(Py_ssize_t arraylen, int nosimd, float *data, float *da
 
 
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 	// SIMD version.
 	if (ignoreerrors && !nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 		if (hasoutputarray) {
@@ -131,7 +136,7 @@ signed int degrees_double(Py_ssize_t arraylen, int nosimd, double *data, double
 
 
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 	// SIMD version.
 	if (ignoreerrors && !nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 		if (hasoutputarray) {
@@ -257,6 +262,7 @@ Call formats: \n\
     degrees(array1, maxlen=y) \n\
     degrees(array1, matherrors=False)) \n\
     degrees(array, nosimd=False) \n\\n\
+\n\
 * array1 - The first input data array to be examined. If no output \n\
   array is provided the results will overwrite the input data. \n\
 * outparray - The output array. This parameter is optional. \n\
