@@ -39,10 +39,15 @@
 
 #include "simddefs.h"
 
-#ifdef AF_HASSIMD
+#ifdef AF_HASSIMD_X86
 #include "invert_simd_x86.h"
 #endif
 
+#ifdef AF_HASSIMD_ARM
+#include "arm_neon.h"
+#include "invert_simd_arm.h"
+#endif
+
 /*--------------------------------------------------------------------------- */
 
 /*--------------------------------------------------------------------------- */
@@ -58,7 +63,7 @@ void invert_signed_char(Py_ssize_t arraylen, int nosimd, signed char *data, sign
 	Py_ssize_t x;
 
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 	// SIMD version.
 	if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 		if (hasoutputarray) {
@@ -96,7 +101,7 @@ void invert_unsigned_char(Py_ssize_t arraylen, int nosimd, unsigned char *data,
 	Py_ssize_t x;
 
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 	// SIMD version.
 	if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 		if (hasoutputarray) {
@@ -134,7 +139,7 @@ void invert_signed_short(Py_ssize_t arraylen, int nosimd, signed short *data, si
 	Py_ssize_t x;
 
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 	// SIMD version.
 	if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 		if (hasoutputarray) {
@@ -172,7 +177,7 @@ void invert_unsigned_short(Py_ssize_t arraylen, int nosimd, unsigned short *data
 	Py_ssize_t x;
 
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 	// SIMD version.
 	if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 		if (hasoutputarray) {
@@ -210,7 +215,7 @@ void invert_signed_int(Py_ssize_t arraylen, int nosimd, signed int *data, signed
 	Py_ssize_t x;
 
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 	// SIMD version.
 	if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 		if (hasoutputarray) {
@@ -248,7 +253,7 @@ void invert_unsigned_int(Py_ssize_t arraylen, int nosimd, unsigned int *data, un
 	Py_ssize_t x;
 
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 	// SIMD version.
 	if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 		if (hasoutputarray) {
