@@ -41,10 +41,16 @@
 
 #include "simddefs.h"
 
-#ifdef AF_HASSIMD
+#ifdef AF_HASSIMD_X86
 #include "sub_simd_x86.h"
 #endif
 
+#ifdef AF_HASSIMD_ARM
+#include "arm_neon.h"
+#include "sub_simd_arm.h"
+#endif
+
+
 /*--------------------------------------------------------------------------- */
 
 /*--------------------------------------------------------------------------- */
@@ -66,7 +72,7 @@ signed int sub_signed_char_1(Py_ssize_t arraylen, int nosimd, signed char *data1
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_signed_char_1_simd(arraylen, data1, param);
@@ -112,7 +118,7 @@ signed int sub_signed_char_2(Py_ssize_t arraylen, int nosimd, signed char *data1
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_signed_char_2_simd(arraylen, data1, param, data3);
@@ -159,7 +165,7 @@ signed int sub_signed_char_3(Py_ssize_t arraylen, int nosimd, signed char param,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_signed_char_3_simd(arraylen, param, data2);
@@ -208,7 +214,7 @@ signed int sub_signed_char_4(Py_ssize_t arraylen, int nosimd, signed char param,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_signed_char_4_simd(arraylen, param, data2, data3);
@@ -258,7 +264,7 @@ signed int sub_signed_char_5(Py_ssize_t arraylen, int nosimd, signed char *data1
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_signed_char_5_simd(arraylen, data1, data2);
@@ -290,7 +296,7 @@ signed int sub_signed_char_6(Py_ssize_t arraylen, int nosimd, signed char *data1
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_signed_char_6_simd(arraylen, data1, data2, data3);
@@ -331,7 +337,7 @@ signed int sub_unsigned_char_1(Py_ssize_t arraylen, int nosimd, unsigned char *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_unsigned_char_1_simd(arraylen, data1, param);
@@ -362,7 +368,7 @@ signed int sub_unsigned_char_2(Py_ssize_t arraylen, int nosimd, unsigned char *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_unsigned_char_2_simd(arraylen, data1, param, data3);
@@ -393,7 +399,7 @@ signed int sub_unsigned_char_3(Py_ssize_t arraylen, int nosimd, unsigned char pa
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_unsigned_char_3_simd(arraylen, param, data2);
@@ -424,7 +430,7 @@ signed int sub_unsigned_char_4(Py_ssize_t arraylen, int nosimd, unsigned char pa
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_unsigned_char_4_simd(arraylen, param, data2, data3);
@@ -457,7 +463,7 @@ signed int sub_unsigned_char_5(Py_ssize_t arraylen, int nosimd, unsigned char *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_unsigned_char_5_simd(arraylen, data1, data2);
@@ -488,7 +494,7 @@ signed int sub_unsigned_char_6(Py_ssize_t arraylen, int nosimd, unsigned char *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
 			sub_unsigned_char_6_simd(arraylen, data1, data2, data3);
@@ -529,7 +535,7 @@ signed int sub_signed_short_1(Py_ssize_t arraylen, int nosimd, signed short *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_signed_short_1_simd(arraylen, data1, param);
@@ -575,7 +581,7 @@ signed int sub_signed_short_2(Py_ssize_t arraylen, int nosimd, signed short *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_signed_short_2_simd(arraylen, data1, param, data3);
@@ -622,7 +628,7 @@ signed int sub_signed_short_3(Py_ssize_t arraylen, int nosimd, signed short para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_signed_short_3_simd(arraylen, param, data2);
@@ -671,7 +677,7 @@ signed int sub_signed_short_4(Py_ssize_t arraylen, int nosimd, signed short para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_signed_short_4_simd(arraylen, param, data2, data3);
@@ -721,7 +727,7 @@ signed int sub_signed_short_5(Py_ssize_t arraylen, int nosimd, signed short *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_signed_short_5_simd(arraylen, data1, data2);
@@ -753,7 +759,7 @@ signed int sub_signed_short_6(Py_ssize_t arraylen, int nosimd, signed short *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_signed_short_6_simd(arraylen, data1, data2, data3);
@@ -794,7 +800,7 @@ signed int sub_unsigned_short_1(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_unsigned_short_1_simd(arraylen, data1, param);
@@ -825,7 +831,7 @@ signed int sub_unsigned_short_2(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_unsigned_short_2_simd(arraylen, data1, param, data3);
@@ -856,7 +862,7 @@ signed int sub_unsigned_short_3(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_unsigned_short_3_simd(arraylen, param, data2);
@@ -887,7 +893,7 @@ signed int sub_unsigned_short_4(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_unsigned_short_4_simd(arraylen, param, data2, data3);
@@ -920,7 +926,7 @@ signed int sub_unsigned_short_5(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_unsigned_short_5_simd(arraylen, data1, data2);
@@ -951,7 +957,7 @@ signed int sub_unsigned_short_6(Py_ssize_t arraylen, int nosimd, unsigned short
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86) || defined(AF_HASSIMD_ARM)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
 			sub_unsigned_short_6_simd(arraylen, data1, data2, data3);
@@ -992,7 +998,7 @@ signed int sub_signed_int_1(Py_ssize_t arraylen, int nosimd, signed int *data1,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_signed_int_1_simd(arraylen, data1, param);
@@ -1038,7 +1044,7 @@ signed int sub_signed_int_2(Py_ssize_t arraylen, int nosimd, signed int *data1,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_signed_int_2_simd(arraylen, data1, param, data3);
@@ -1085,7 +1091,7 @@ signed int sub_signed_int_3(Py_ssize_t arraylen, int nosimd, signed int param, s
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_signed_int_3_simd(arraylen, param, data2);
@@ -1134,7 +1140,7 @@ signed int sub_signed_int_4(Py_ssize_t arraylen, int nosimd, signed int param, s
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_signed_int_4_simd(arraylen, param, data2, data3);
@@ -1184,7 +1190,7 @@ signed int sub_signed_int_5(Py_ssize_t arraylen, int nosimd, signed int *data1,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_signed_int_5_simd(arraylen, data1, data2);
@@ -1216,7 +1222,7 @@ signed int sub_signed_int_6(Py_ssize_t arraylen, int nosimd, signed int *data1,
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_signed_int_6_simd(arraylen, data1, data2, data3);
@@ -1257,7 +1263,7 @@ signed int sub_unsigned_int_1(Py_ssize_t arraylen, int nosimd, unsigned int *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_unsigned_int_1_simd(arraylen, data1, param);
@@ -1288,7 +1294,7 @@ signed int sub_unsigned_int_2(Py_ssize_t arraylen, int nosimd, unsigned int *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_unsigned_int_2_simd(arraylen, data1, param, data3);
@@ -1319,7 +1325,7 @@ signed int sub_unsigned_int_3(Py_ssize_t arraylen, int nosimd, unsigned int para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_unsigned_int_3_simd(arraylen, param, data2);
@@ -1350,7 +1356,7 @@ signed int sub_unsigned_int_4(Py_ssize_t arraylen, int nosimd, unsigned int para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_unsigned_int_4_simd(arraylen, param, data2, data3);
@@ -1383,7 +1389,7 @@ signed int sub_unsigned_int_5(Py_ssize_t arraylen, int nosimd, unsigned int *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_unsigned_int_5_simd(arraylen, data1, data2);
@@ -1414,7 +1420,7 @@ signed int sub_unsigned_int_6(Py_ssize_t arraylen, int nosimd, unsigned int *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
 			sub_unsigned_int_6_simd(arraylen, data1, data2, data3);
@@ -2188,7 +2194,7 @@ signed int sub_float_1(Py_ssize_t arraylen, int nosimd, float *data1, float para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			sub_float_1_simd(arraylen, data1, param);
@@ -2219,7 +2225,7 @@ signed int sub_float_2(Py_ssize_t arraylen, int nosimd, float *data1, float para
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			sub_float_2_simd(arraylen, data1, param, data3);
@@ -2250,7 +2256,7 @@ signed int sub_float_3(Py_ssize_t arraylen, int nosimd, float param, float *data
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			sub_float_3_simd(arraylen, param, data2);
@@ -2281,7 +2287,7 @@ signed int sub_float_4(Py_ssize_t arraylen, int nosimd, float param, float *data
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			sub_float_4_simd(arraylen, param, data2, data3);
@@ -2314,7 +2320,7 @@ signed int sub_float_5(Py_ssize_t arraylen, int nosimd, float *data1, float *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			sub_float_5_simd(arraylen, data1, data2);
@@ -2345,7 +2351,7 @@ signed int sub_float_6(Py_ssize_t arraylen, int nosimd, float *data1, float *dat
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
 			sub_float_6_simd(arraylen, data1, data2, data3);
@@ -2385,7 +2391,7 @@ signed int sub_double_1(Py_ssize_t arraylen, int nosimd, double *data1, double p
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			sub_double_1_simd(arraylen, data1, param);
@@ -2416,7 +2422,7 @@ signed int sub_double_2(Py_ssize_t arraylen, int nosimd, double *data1, double p
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			sub_double_2_simd(arraylen, data1, param, data3);
@@ -2447,7 +2453,7 @@ signed int sub_double_3(Py_ssize_t arraylen, int nosimd, double param, double *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			sub_double_3_simd(arraylen, param, data2);
@@ -2478,7 +2484,7 @@ signed int sub_double_4(Py_ssize_t arraylen, int nosimd, double param, double *d
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			sub_double_4_simd(arraylen, param, data2, data3);
@@ -2511,7 +2517,7 @@ signed int sub_double_5(Py_ssize_t arraylen, int nosimd, double *data1, double *
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			sub_double_5_simd(arraylen, data1, data2);
@@ -2542,7 +2548,7 @@ signed int sub_double_6(Py_ssize_t arraylen, int nosimd, double *data1, double *
 	// Math error checking disabled.
 	if (ignoreerrors) {
 
-#ifdef AF_HASSIMD
+#if defined(AF_HASSIMD_X86)
 		// SIMD version.
 		if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
 			sub_double_6_simd(arraylen, data1, data2, data3);
@@ -3026,6 +3032,7 @@ Call formats: \n\
   sub(array1, param, maxlen=y) \n\
   sub(array1, param, matherrors=False) \n\
   sub(array, param, nosimd=False)\n\
+\n\
 * array1 - The first input data array to be examined. If no output  \n\
   array is provided the results will overwrite the input data.  \n\
 * param - A non-array numeric parameter.  \n\
